summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-12 21:41:38 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-13 06:47:08 -0600
commit6df21524cd315f661b3f997fede65dfda7d4d37b (patch)
tree23f26bd56f824fe913963ed43457829059a7825c /png.h
parentfa49aae286c5de4dade7226594f1942bfed3a996 (diff)
downloadlibpng-6df21524cd315f661b3f997fede65dfda7d4d37b.tar.gz
[libpng16] Imported from libpng-1.6.15rc01.tarv1.6.15rc01
Diffstat (limited to 'png.h')
-rw-r--r--png.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/png.h b/png.h
index 0082126e2..ff9393c87 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.15beta08 - November 8, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.15beta08 - November 8, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -207,6 +207,7 @@
* 1.6.14rc01-02 16 10614 16.so.16.14[.0]
* 1.6.14 16 10614 16.so.16.14[.0]
* 1.6.15beta01-08 16 10615 16.so.16.15[.0]
+ * 1.6.15rc01 16 10615 16.so.16.15[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -238,7 +239,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.15beta08, November 8, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -350,13 +351,13 @@
* Y2K compliance in libpng:
* =========================
*
- * November 8, 2014
+ * November 13, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.15beta08 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -418,9 +419,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.15beta08"
+#define PNG_LIBPNG_VER_STRING "1.6.15rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.15beta08 - November 8, 2014\n"
+ " libpng version 1.6.15rc01 - November 13, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -434,7 +435,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 08
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -451,7 +452,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -564,7 +565,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_15beta08;
+typedef char* png_libpng_version_1_6_15rc01;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.15beta08 - November 8, 2014
+ * libpng version 1.6.15rc01 - November 13, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.15beta08 - November 8, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.15rc01 - November 13, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -238,7 +239,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.15beta08, November 8, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.15rc01, November 13, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -350,13 +351,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.15beta08 are Y2K compliant. It is my belief that
+ * upward through 1.6.15rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*